// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  TU Dresden                                                            ==
// ==                                                                        ==
// ==  Institut fr Wissenschaftliches Rechnen                               ==
// ==  Zellescher Weg 12-14                                                  ==
// ==  01069 Dresden                                                         ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  https://gforge.zih.tu-dresden.de/projects/amdis/                      ==
// ==                                                                        ==
// ============================================================================

/** \file ConditionalEstimator.h */

/** \defgroup Estimator Estimator module
 * @{ <img src="estimator.png"> @}
 */

#ifndef AMDIS_CONDITIONALESTIMATOR_H
#define AMDIS_CONDITIONALESTIMATOR_H

#include "Estimator.h"

namespace AMDiS {

  /**
   * \ingroup Estimator
   * 
   * \brief
   * Estimator for scalar problems.
   */
  class ConditionalEstimator : public Estimator
  {
  public:
    ConditionalEstimator(Estimator *decorated) 
      : decoratedEstimator_(decorated),
	elementCount_(0), 
	row_(decorated ? decorated->getRow() : 0)
    {}

    double estimate(double timestep);

    inline int getElementCount() 
    {
      return elementCount_;
    }

    inline Estimator *getDecoratedEstimator() 
    { 
      return decoratedEstimator_; 
    }

  protected:
    Estimator *decoratedEstimator_;

    int elementCount_;

    int row_;
  };

}

#endif // AMDIS_ESTIMATOR_H
